Dijit Tree Test

# Dijit Tree Test - Drag And Drop Support

## Items:

List of Items to be categorized

Apple
Orange
Banana
Tomato
Pepper
Wheat
Corn
Spinach
Cucumber
Carrot
Potato
Grape
Lemon
Lettuce
Peanut

## Collection Count Summary

You can't drop items onto this tree, but you can reorder categories. The between threshold is set to 5, so if you are near the top or bottom of a node the drop will be above or below it.

## Custom

Should add this category to the store. The second parameter is the value for numberOfItems.

New category: numberOfItems:
Add Category

## Collection

Drop items from table on left onto this tree, only on to categories or between other items; should fail to let you drop on other items. Can also move items within this tree. The drag threshold is set to 8, between threshold is set to 5, so you have a few pixels of buffer before drag operations start.